==> jc-1.4.0.tar.gz: soot/util/NumberedSet__24BitSetIterator.h <==
// class soot.util.NumberedSet$BitSetIterator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 72e392d229e48533 soot_util_NumberedSet__24BitSetIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_NumberedSet__24BitSetIterator_H_
#define _JC_soot_util_NumberedSet__24BitSetIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_util_BitSetIterator$object;
struct _jc_soot_util_NumberedSet$object;

// Typedefs
typedef struct _jc_soot_util_NumberedSet__24BitSetIterator$sub_refs	_jc_soot_util_NumberedSet__24BitSetIterator$sub_refs;
typedef struct _jc_soot_util_NumberedSet__24BitSetIterator$sub_nonrefs	_jc_soot_util_NumberedSet__24BitSetIterator$sub_nonrefs;
typedef struct _jc_soot_util_NumberedSet__24BitSetIterator$refs	_jc_soot_util_NumberedSet__24BitSetIterator$refs;
typedef struct _jc_soot_util_NumberedSet__24BitSetIterator$nonrefs	_jc_soot_util_NumberedSet__24BitSetIterator$nonrefs;
typedef struct _jc_soot_util_NumberedSet__24BitSetIterator$object	_jc_soot_util_NumberedSet__24BitSetIterator$object;

typedef const struct _jc_soot_util_NumberedSet__24BitSetIterator$vmethods	_jc_soot_util_NumberedSet__24BitSetIterator$vmethods;
typedef const struct _jc_soot_util_NumberedSet__24BitSetIterator$vtable	_jc_soot_util_NumberedSet__24BitSetIterator$vtable;
typedef const struct _jc_soot_util_NumberedSet__24BitSetIterator$vtype	_jc_soot_util_NumberedSet__24BitSetIterator$vtype;

// Constructors
extern void _jc_soot_util_NumberedSet__24BitSetIterator$method$_init$bb89cbca9b373273(_jc_env *, struct _jc_soot_util_NumberedSet__24BitSetIterator$object *, struct _jc_soot_util_NumberedSet$object *, struct _jc_soot_util_NumberedSet$object *);

// Virtual methods
extern jboolean _jc_soot_util_NumberedSet__24BitSetIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_soot_util_NumberedSet__24BitSetIterator$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_util_NumberedSet__24BitSetIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_soot_util_NumberedSet__24BitSetIterator$object *);
extern void _jc_soot_util_NumberedSet__24BitSetIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_soot_util_NumberedSet__24BitSetIterator$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_util_NumberedSet__24BitSetIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_soot_util_NumberedSet__24BitSetIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_soot_util_NumberedSet__24BitSetIterator$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_soot_util_NumberedSet__24BitSetIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_soot_util_NumberedSet__24BitSetIterator$object *);
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_soot_util_NumberedSet__24BitSetIterator$object *);
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_soot_util_NumberedSet__24BitSetIterator$object *);
};

// Vtable
struct _jc_soot_util_NumberedSet__24BitSetIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_NumberedSet__24BitSetIterator$vmethods	soot_util_NumberedSet__24BitSetIterator;
};

// Vtype
struct _jc_soot_util_NumberedSet__24BitSetIterator$vtype {
	_jc_type			type;
	_jc_soot_util_NumberedSet__24BitSetIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_NumberedSet__24BitSetIterator$sub_refs {
	struct _jc_soot_util_BitSetIterator$object	*iter;
	struct _jc_soot_util_NumberedSet$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_util_NumberedSet__24BitSetIterator$refs {
    _jc_soot_util_NumberedSet__24BitSetIterator$sub_refs	soot_util_NumberedSet__24BitSetIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_NumberedSet__24BitSetIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_util_NumberedSet__24BitSetIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_NumberedSet__24BitSetIterator$sub_nonrefs	soot_util_NumberedSet__24BitSetIterator;
};

// Object instance structure
struct _jc_soot_util_NumberedSet__24BitSetIterator$object {
	_jc_soot_util_NumberedSet__24BitSetIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_NumberedSet__24BitSetIterator$vtype	*vtype;
	_jc_soot_util_NumberedSet__24BitSetIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_NumberedSet__24BitSetIterator$vtype _jc_soot_util_NumberedSet__24BitSetIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_NumberedSet__24BitSetIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_NumberedSet__24BitSetIterator$class_object;

#endif	/* _JC_soot_util_NumberedSet__24BitSetIterator_H_ */

==> jc-1.4.6.tar.gz: soot/util/NumberedSet__24BitSetIterator.h <==
// class soot.util.NumberedSet$BitSetIterator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 72e392d229e48533 soot_util_NumberedSet__24BitSetIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_NumberedSet__24BitSetIterator_H_
#define _JC_soot_util_NumberedSet__24BitSetIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_util_BitSetIterator$object;
struct _jc_soot_util_NumberedSet$object;

// Typedefs
typedef struct _jc_soot_util_NumberedSet__24BitSetIterator$sub_refs	_jc_soot_util_NumberedSet__24BitSetIterator$sub_refs;
typedef struct _jc_soot_util_NumberedSet__24BitSetIterator$sub_nonrefs	_jc_soot_util_NumberedSet__24BitSetIterator$sub_nonrefs;
typedef struct _jc_soot_util_NumberedSet__24BitSetIterator$refs	_jc_soot_util_NumberedSet__24BitSetIterator$refs;
typedef struct _jc_soot_util_NumberedSet__24BitSetIterator$nonrefs	_jc_soot_util_NumberedSet__24BitSetIterator$nonrefs;
typedef struct _jc_soot_util_NumberedSet__24BitSetIterator$object	_jc_soot_util_NumberedSet__24BitSetIterator$object;

typedef const struct _jc_soot_util_NumberedSet__24BitSetIterator$vmethods	_jc_soot_util_NumberedSet__24BitSetIterator$vmethods;
typedef const struct _jc_soot_util_NumberedSet__24BitSetIterator$vtable	_jc_soot_util_NumberedSet__24BitSetIterator$vtable;
typedef const struct _jc_soot_util_NumberedSet__24BitSetIterator$vtype	_jc_soot_util_NumberedSet__24BitSetIterator$vtype;

// Constructors
extern void _jc_soot_util_NumberedSet__24BitSetIterator$method$_init$bb89cbca9b373273(_jc_env *, struct _jc_soot_util_NumberedSet__24BitSetIterator$object *, struct _jc_soot_util_NumberedSet$object *, struct _jc_soot_util_NumberedSet$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_util_NumberedSet__24BitSetIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_soot_util_NumberedSet__24BitSetIterator$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_util_NumberedSet__24BitSetIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_soot_util_NumberedSet__24BitSetIterator$object *) _JC_JCNI_ATTR;
extern void _jc_soot_util_NumberedSet__24BitSetIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_soot_util_NumberedSet__24BitSetIterator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_util_NumberedSet__24BitSetIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_soot_util_NumberedSet__24BitSetIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_soot_util_NumberedSet__24BitSetIterator$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_soot_util_NumberedSet__24BitSetIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_soot_util_NumberedSet__24BitSetIterator$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_soot_util_NumberedSet__24BitSetIterator$object *) _JC_JCNI_ATTR;
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_soot_util_NumberedSet__24BitSetIterator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_util_NumberedSet__24BitSetIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_NumberedSet__24BitSetIterator$vmethods	soot_util_NumberedSet__24BitSetIterator;
};

// Vtype
struct _jc_soot_util_NumberedSet__24BitSetIterator$vtype {
	_jc_type			type;
	_jc_soot_util_NumberedSet__24BitSetIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_NumberedSet__24BitSetIterator$sub_refs {
	struct _jc_soot_util_BitSetIterator$object	*iter;
	struct _jc_soot_util_NumberedSet$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_util_NumberedSet__24BitSetIterator$refs {
    _jc_soot_util_NumberedSet__24BitSetIterator$sub_refs	soot_util_NumberedSet__24BitSetIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_NumberedSet__24BitSetIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_util_NumberedSet__24BitSetIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_NumberedSet__24BitSetIterator$sub_nonrefs	soot_util_NumberedSet__24BitSetIterator;
};

// Object instance structure
struct _jc_soot_util_NumberedSet__24BitSetIterator$object {
	_jc_soot_util_NumberedSet__24BitSetIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_NumberedSet__24BitSetIterator$vtype	*vtype;
	_jc_soot_util_NumberedSet__24BitSetIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_NumberedSet__24BitSetIterator$vtype _jc_soot_util_NumberedSet__24BitSetIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_NumberedSet__24BitSetIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_NumberedSet__24BitSetIterator$class_object;

#endif	/* _JC_soot_util_NumberedSet__24BitSetIterator_H_ */
